<?php

namespace Drupal\group_permissions_template\EventSubscriber;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Drupal\group_permissions_template\Service\PermissionTemplatesInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class ConfigImportSubscriber implements EventSubscriberInterface {

  /**
   * Group permissions template service.
   *
   * @var PermissionTemplatesInterface
   */
  protected $permissionTemplateService;

  /**
   * Constructs a new ConfigImportSubscriber object.
   *
   * @param PermissionTemplatesInterface $permission_template_services
   *    Group permissions template service.
   */
  public function __construct(PermissionTemplatesInterface $permission_template_services) {
    $this->permissionTemplateService = $permission_template_services;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[ConfigEvents::SAVE][] = ['applyConfigAfterImport'];
    return $events;
  }

  /**
   * Group permissions template configurations should be applied after configs are imported.
   *
   * @return void
   */
  public function applyConfigAfterImport(ConfigCrudEvent $event) {
    /** @var Config $config */
    $config = $event->getConfig();

    if (str_starts_with($config->getName(), 'group_permissions_template.group_permission_template.')) {
      $this->permissionTemplateService->updateGroupsPermissions($config->get('id'));
    }
  }

}
